==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetDatabasePrincipalAssignmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of the database in the Kusto pool.
 * @property kustoPoolName The name of the Kusto pool.
 * @property principalAssignmentName The name of the Kusto principalAssignment.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace
 */
public data class GetDatabasePrincipalAssignmentPlainArgs(
    public val databaseName: String,
    public val kustoPoolName: String,
    public val principalAssignmentName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs.builder()
            .databaseName(databaseName.let({ args0 -> args0 }))
            .kustoPoolName(kustoPoolName.let({ args0 -> args0 }))
            .principalAssignmentName(principalAssignmentName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDatabasePrincipalAssignmentPlainArgs].
 */
@PulumiTagMarker
public class GetDatabasePrincipalAssignmentPlainArgsBuilder internal constructor() {
    private var databaseName: String? = null

    private var kustoPoolName: String? = null

    private var principalAssignmentName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the database in the Kusto pool.
     */
    @JvmName("csfauqljpwebirgg")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the Kusto pool.
     */
    @JvmName("tscfdypvbttkpuud")
    public suspend fun kustoPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.kustoPoolName = mapped
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("phfvafbjjakvuyty")
    public suspend fun principalAssignmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.principalAssignmentName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ejjimpqnovxcufiw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace
     */
    @JvmName("ndtqninoxfpgadii")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetDatabasePrincipalAssignmentPlainArgs =
        GetDatabasePrincipalAssignmentPlainArgs(
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            kustoPoolName = kustoPoolName ?: throw PulumiNullFieldException("kustoPoolName"),
            principalAssignmentName = principalAssignmentName ?: throw
                PulumiNullFieldException("principalAssignmentName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetDatabasePrincipalAssignmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of the database in the Kusto pool.
 * @property kustoPoolName The name of the Kusto pool.
 * @property principalAssignmentName The name of the Kusto principalAssignment.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace
 */
public data class GetDatabasePrincipalAssignmentPlainArgs(
    public val databaseName: String,
    public val kustoPoolName: String,
    public val principalAssignmentName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetDatabasePrincipalAssignmentPlainArgs.builder()
            .databaseName(databaseName.let({ args0 -> args0 }))
            .kustoPoolName(kustoPoolName.let({ args0 -> args0 }))
            .principalAssignmentName(principalAssignmentName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDatabasePrincipalAssignmentPlainArgs].
 */
@PulumiTagMarker
public class GetDatabasePrincipalAssignmentPlainArgsBuilder internal constructor() {
    private var databaseName: String? = null

    private var kustoPoolName: String? = null

    private var principalAssignmentName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the database in the Kusto pool.
     */
    @JvmName("mtfpedspodxbuego")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the Kusto pool.
     */
    @JvmName("irmekltwgcjevrdl")
    public suspend fun kustoPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.kustoPoolName = mapped
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("rwxdcypjivgxmubs")
    public suspend fun principalAssignmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.principalAssignmentName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nlhtxeglaxqrdeel")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace
     */
    @JvmName("knjebqlgupwbrjoc")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetDatabasePrincipalAssignmentPlainArgs =
        GetDatabasePrincipalAssignmentPlainArgs(
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            kustoPoolName = kustoPoolName ?: throw PulumiNullFieldException("kustoPoolName"),
            principalAssignmentName = principalAssignmentName ?: throw
                PulumiNullFieldException("principalAssignmentName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}
